@@ -1,4 +1,4 @@
-#ident "$Id: mkzftree.h,v 1.5 2003/07/11 03:24:01 hpa Exp $"
+#ident "$Id: mkzftree.h,v 1.6 2004/07/20 04:04:22 hpa Exp $"
 /* ----------------------------------------------------------------------- *
  *   
  *   Copyright 2001 H. Peter Anvin - All Rights Reserved
@@ -84,6 +84,7 @@ void end_worker(int);
 
 /* util.c */
 void *xmalloc(size_t);
+void *xrealloc(void *, size_t);
 char *xstrdup(const char *);
 void message(enum verbosity, const char *, ...);
 
@@ -91,3 +92,6 @@ void message(enum verbosity, const char *, ...);
 const char *hash_find_file(struct stat *);
 void hash_insert_file(struct stat *, const char *);
 
+/* copytime.h */
+int copytime(const char *, const struct stat *);
+
